@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.c,v 1.91 2007/10/18 21:51:43 evertonm Exp $ */
+/* $Id: common.c,v 1.93 2007/10/19 20:10:18 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -53,7 +53,7 @@ static int line = 0;
 
 const char *nepim_version()
 {
-  return "0.43";
+  return "0.44";
 }
 
 static void header(FILE *out, int ident, int udp)
@@ -206,16 +206,23 @@ void nepim_slot_stat(FILE *out, struct timeval now,
 		   min, max);
 
   {
-    float loss_ratio = pkt_lost;
-    float ooo_ratio  = pkt_ooo;
+    float loss_ratio;
+    float ooo_ratio;
 
 #if 0
-    loss_ratio *= 100;
-    ooo_ratio  *= 100;
+    fprintf(stderr, "DEBUG common.c pkt_expected = %llu\n", pkt_expected);
 #endif
-    
-    loss_ratio /= pkt_expected;
-    ooo_ratio  /= pkt_expected;
+
+    if (pkt_expected) {
+      loss_ratio = pkt_lost;
+      ooo_ratio  = pkt_ooo;
+      loss_ratio /= pkt_expected;
+      ooo_ratio  /= pkt_expected;
+    }
+    else {
+      loss_ratio = 0;
+      ooo_ratio  = 0;
+    }
 
     MIN_UPDATE(loss_ratio, min->pkt_loss);
     MIN_UPDATE(ooo_ratio, min->pkt_ooo);
@@ -223,13 +230,6 @@ void nepim_slot_stat(FILE *out, struct timeval now,
     MAX_UPDATE(loss_ratio, max->pkt_loss);
     MAX_UPDATE(ooo_ratio, max->pkt_ooo);
 
-#if 0
-    fprintf(out,
-            " %-5.4f %-5.4f",
-            loss_ratio,
-	    ooo_ratio);
-#endif
-    
     dump_ratio(out, loss_ratio);
     dump_ratio(out, ooo_ratio);
   }
