@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.h,v 1.29 2007/08/30 15:08:00 evertonm Exp $ */
+/* $Id: common.h,v 1.30 2007/10/18 21:51:43 evertonm Exp $ */
 
 #ifndef NEPIM_COMMON_H
 #define NEPIM_COMMON_H
@@ -50,7 +50,9 @@ void nepim_pipe_stat(FILE *out, struct timeval now,
 		     const char *label, int sd,
                      long long bytes_recv, long long bytes_sent, 
                      float interval, long sec_start, 
-                     long sec_duration, int reads, int writes);
+                     long sec_duration, int reads, int writes,
+		     nepim_mark_t *min, nepim_mark_t *max,
+		     int report_min_max);
 
 void nepim_slot_stat(FILE *out, struct timeval now,
 		     const char *label, int sd,
@@ -59,12 +61,14 @@ void nepim_slot_stat(FILE *out, struct timeval now,
                      float interval, long sec_start, 
                      long sec_duration, int reads, int writes,
                      uint64_t pkt_expected, uint64_t pkt_lost,
-		     uint64_t pkt_ooo, uint64_t acc_pkt_lost);
+		     uint64_t pkt_ooo, uint64_t acc_pkt_lost,
+		     nepim_mark_t *min, nepim_mark_t *max,
+		     int report_min_max);
 
-void report_broken_pipe_stat(FILE *out, const nepim_pipe_t *pipe);
+void report_broken_pipe_stat(FILE *out, nepim_pipe_t *pipe);
 void report_broken_slot_stat(FILE *out, nepim_slot_t *slot);
 
-void report_broken_pipe_stat_at(FILE *out, const nepim_pipe_t *pipe,
+void report_broken_pipe_stat_at(FILE *out, nepim_pipe_t *pipe,
 				struct timeval now);
 void report_broken_slot_stat_at(FILE *out, nepim_slot_t *slot,
 				struct timeval now);
