@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.67 2007/08/17 17:12:48 evertonm Exp $
+  $Id: main.c,v 1.69 2007/10/18 21:51:43 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -116,9 +116,10 @@ static void usage(FILE *out, const char *prog_name)
 	  "  -Fa            same as -F plus randomize destination address\n"
 	  "  -Fp            same as -F plus randomize destination port\n"
 	  "                 if -c is omitted, either 'a' or 'p' implies -c 1.1.1.1\n"
+	  "                 hint: use '-c ::1 -Fa' to randomize IPv6 addresses\n"
           "  -M             enable multicast-compatible options\n"
 	  "  -o [overhead]  protocol per-packet overhead in bytes (defaults to none)\n"
-	  "                 if the optional 'overhead' argument is ommited:\n"
+	  "                 if the optional 'overhead' argument is omitted:\n"
 	  "                 UDP overhead defaults to %d\n"
 	  "                 TCP overhead defaults to %d\n"
           "  -n pipes       number of parallel pipes (defaults to %d)\n"
@@ -148,6 +149,7 @@ static void usage(FILE *out, const char *prog_name)
 	  "                 'interval' can't be lower than %ld us\n"
 	  "  -K udp-ka-time UDP keepalive timeout (defaults to %ld us)\n"
 	  "                 'udp-ka-time' can't be lower than %ld us\n"
+	  "  -mM            report periodic (per-interval) min-MAX rates\n"
 	  "  -N nagle       TCP nagle mode (defaults to %d)\n"
 	  "                 nagle: -1 = use system's default\n"
 	  "                         0 = off (enable TCP_NODELAY)\n"
@@ -653,6 +655,11 @@ int main(int argc, const char *argv[])
       continue;
     }
 
+    if (!strcmp(arg, "-mM")) {
+      nepim_global.report_partial_min_max = 1; /* boolean = true */
+      continue;
+    }
+
     if (!strncmp(arg, "-F", 2)) {
       nepim_global.udp_mode                = 1; /* -u (UDP) */
       nepim_global.simplex_client_send     = 1; /* -s (client-send) */
