@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.106 2007/08/30 15:08:01 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.107 2007/10/18 21:51:44 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -83,7 +83,10 @@ static void *on_udp_interval(oop_source *src, struct timeval tv, void *user)
 		  slot->seq_highest_recv - slot->interval_last_highest_seq,
 		  slot->interval_pkt_lost,
 		  slot->interval_pkt_ooo,
-		  slot->total_pkt_lost);
+		  slot->total_pkt_lost,
+		  &session->min,
+		  &session->max,
+		  session->report_partial_min_max);
 
   session->byte_interval_recv = 0;
   session->byte_interval_sent = 0;
@@ -146,7 +149,10 @@ static void *on_udp_duration(oop_source *src, struct timeval tv, void *user)
 		  slot->seq_highest_recv,
 		  slot->total_pkt_lost,
 		  slot->total_pkt_ooo,
-		  slot->total_pkt_lost);
+		  slot->total_pkt_lost,
+		  &session->min,
+		  &session->max,
+		  1 /* report_min_max = true */);
 
   session->byte_total_recv = 0;
   session->byte_total_sent = 0;
@@ -806,7 +812,7 @@ static int parse_greetings(nepim_greet_t *opt,
           "seed=0x%08x verify_data=%d random_fill=%d fill_byte=0x%02x pause_duration=%d "
 	  "sock_ka=%d overhead=%d "
 	  "sweep_random=%d sweep_step=%d write_floor=%d write_ceil=%d "
-	  "password=%s\n", 
+	  "p_minmax=%d password=%s\n", 
 	  sd, 
 	  local_slot, remote_slot,
 	  peer,
@@ -820,6 +826,7 @@ static int parse_greetings(nepim_greet_t *opt,
 	  opt->pause_duration, opt->socket_keepalive,
 	  opt->overhead,
 	  opt->sweep_random, opt->sweep_step, opt->write_floor, opt->write_ceil,
+	  opt->report_partial_min_max,
 	  password_buf);
 
   nepim_conf_write_sweep_auto(1 /* udp=true */,
